@@ -41,7 +41,7 @@ class CattleHead():
         gh = github3.login(token=self._token)
         self._repo = gh.repository(self._org, self._repo_name)
         self._description = self._repo.description
-        self._changelog_url = f"http://{self._org}.github.io/{self._repo_name}/pdsen-corral/CHANGELOG.html"
+        self._changelog_url = f'https://github.com/{self._org}/{self._repo_name}/blob/master/CHANGELOG.md'
         self._changelog_signets = self._get_changelog_signet()
         self._dev = dev
 
@@ -99,9 +99,9 @@ class CattleHead():
             return "https://www.gnupg.org/gph/en/manual/r1943.html"
 
     def _get_requirements_link(self):
-        url = f'https://{self._org}.github.io/{self._repo_name}/pdsen-corral/{self._version_name}/REQUIREMENTS.html'
+        url = f'https://github.com/{self._org}/{self._repo_name}/blob/master/docs/requirements/{self._version_name}/REQUIREMENTS.md'
         logger.info(f'try url {url} for requirements')
-        if self._version_name and requests.get(url).status_code != 404:
+        if self._version_name and requests.get(url, timeout=5).status_code != 404:
             return url
         else:
             return None
@@ -120,7 +120,7 @@ class CattleHead():
 
         return [self._name,
                 self._version_name if self._version_name else "None",
-                self._update.strftime('%y-%m-%d') if self._update else "Not yet",
+                self._update.strftime('%Y-%m-%d') if self._update else "N/A",
                 description,
                 *icon_cells
         ]
@@ -131,8 +131,20 @@ class CattleHead():
         soup = BeautifulSoup(changelog.content, 'html.parser')
         changelog_signets = {}
         for h2 in soup.find_all('h2'):
-            changelog_signets[h2.find("a").text] = "#".join([self._changelog_url, h2.get('id')])
+            version , signet = self._extract_signet_from_h2(h2)
+            if version:
+                changelog_signets[version] = signet
 
         return changelog_signets
 
+    def _extract_signet_from_h2(self, h2_tag):
+        a_tags = h2_tag.find_all("a")
+        if len(a_tags) == 2:
+            href_attr = a_tags[0].get('href')
+            if href_attr:
+                return a_tags[1].text, ''.join([self._changelog_url, href_attr])
+
+        return None, None
+
+
 
